@@ -301,6 +301,7 @@ button_press(GtkWidget* widget, GdkEventButton *event)
 /*   dbus_connection_flush(bus); */
 /*   dbus_message_unref(message); */
 /*   dbus_connection_unref(bus); */
+
   DateTodayPlugin *desktop_plugin = DATE_TODAY_PLUGIN(widget);
   DBusGConnection *dbus_conn = hd_home_plugin_item_get_dbus_g_connection ( &desktop_plugin->hitem, 
 									   DBUS_BUS_SESSION, 
@@ -357,7 +358,10 @@ date_today_plugin_class_init(DateTodayPluginClass *klass)
   GtkWidgetClass *widget_class = GTK_WIDGET_CLASS(klass);
   widget_class->realize = example_realize;
   widget_class->expose_event = example_expose;
-  widget_class->button_press_event = button_press;
+//Define button_release_event instead of button_press_event to avoid calendar application execution during scrolling between desktops
+  //widget_class->button_press_event = button_press;
+  widget_class->button_release_event = button_press;
+//------------------------------------------------------------------------------------------------László Tari <n900nseries@gmail.com>
   G_OBJECT_CLASS(klass)->finalize = date_today_plugin_finalize;
 }
 
